
Relays
======


.. automodule:: opendssdirect.Relays
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Relays.AllNames

    Get a vector of strings containing names of all relay elements.

.. function:: opendssdirect.Relays.Count

    Get number of Relays in active circuit.

.. function:: opendssdirect.Relays.First

    Set first relay active. If none, returns 0.

.. function:: opendssdirect.Relays.Idx

    Get the active relay by index into the Relay list. 1..Count.Set the active relay by index into the Relay list. 1..Count.

.. function:: opendssdirect.Relays.MonitoredObj

    Get the full name of the object this relay is monitoring.Set the full name of the object this relay is monitoring.

.. function:: opendssdirect.Relays.MonitoredTerm

    Get the number of terminal of monitored element that this relay is monitoring.Set the number of terminal of monitored element that this relay is monitoring.

.. function:: opendssdirect.Relays.Name

    Get the name of the active Relay.Set the name of the active Relay.

.. function:: opendssdirect.Relays.Next

    Set next relay active. If none, returns 0.

.. function:: opendssdirect.Relays.SwitchedObj

    Get the full name of element that will switched when relay trips.Set the full name of element that will switched when relay trips.

.. function:: opendssdirect.Relays.SwitchedTerm

    Get the number of terminal of the switched object that will be opened when the relay trips.Set the number of terminal of the switched object that will be opened when the relay trips.

